<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>Data::StatusIconSettings</name>
    <message>
        <location filename="../syncthingicons.cpp" line="232"/>
        <source>Misc. notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="233"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="234"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="235"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="236"/>
        <source>Scanning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="237"/>
        <source>Synchronizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="238"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="239"/>
        <source>Disconnected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDeviceModel</name>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="86"/>
        <location filename="../syncthingdevicemodel.cpp" line="118"/>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="88"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="120"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="122"/>
        <source>Connection type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="124"/>
        <source>Last seen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="126"/>
        <source>Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="128"/>
        <source>Certificate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="130"/>
        <source>Introducer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="132"/>
        <source>Incoming traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="134"/>
        <source>Outgoing traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="136"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="162"/>
        <source>unknown or this device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="167"/>
        <source>none</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>no</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDirectoryModel</name>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
        <source>Rescan interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
        <source>Last scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
        <source>Last file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
        <source>none</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
        <source>%1 item(s) out of sync</source>
        <translation>
            <numerusform>%1 item out of sync</numerusform>
            <numerusform>%1 items out of sync</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
        <source>Global status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
        <source>Local status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
        <source>Shared with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
        <source>not shared</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
        <source>%1 and %2 item(s) out of sync</source>
        <translation>
            <numerusform>%1 and %2 item out of sync</numerusform>
            <numerusform>%1 and %2 items out of sync</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="260"/>
        <source>Deleted at %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="263"/>
        <source>Updated at %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="275"/>
        <source>Failed items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="276"/>
        <source>Click for details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDownloadModel</name>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
        <source>Dir/item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingErrorModel</name>
    <message>
        <location filename="../syncthingerrormodel.cpp" line="62"/>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingerrormodel.cpp" line="64"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingFileModel</name>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="291"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="293"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="295"/>
        <source>Last modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="297"/>
        <source>Ignore pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="345"/>
        <source>%1 elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="226"/>
        <source>Exists locally and globally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="228"/>
        <source>Exists only globally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="230"/>
        <source>Exists only locally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="232"/>
        <source>Does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="462"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="465"/>
        <source>Deselect recursively</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="465"/>
        <source>Select recursively</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="467"/>
        <source>Deselect single item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="467"/>
        <source>Select single item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="469"/>
        <source>Open local version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="469"/>
        <source>Copy local path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="469"/>
        <source>Browse locally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="746"/>
        <source>Select items to sync/ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="752"/>
        <source>Discard staged changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="762"/>
        <source>Discard selection and staged changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="775"/>
        <source>Ignore selected items (and their children)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="780"/>
        <source>Include selected items (and their children)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="787"/>
        <source>Include all items by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="787"/>
        <source>Ignore all items by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="817"/>
        <source>Remove ignore patterns matching against selected items (may affect other items as well)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="845"/>
        <source>Review and apply staged changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="852"/>
        <source>Do you want to apply the following changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="860"/>
        <source>Cannot apply ignore patterns while a previous request for ignore patterns is still pending.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="868"/>
        <source>Unable to change ignore patterns:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="882"/>
        <source>Ignore patterns have been changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="1057"/>
        <source>Cannot query ignore patterns while a previous request for ignore patterns is still pending.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingRecentChangesModel</name>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="69"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="117"/>
        <source>Locally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="117"/>
        <source>Remotely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingStatusComputionModel</name>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="37"/>
        <source>Local dir is scanning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="39"/>
        <source>Local dir is synchronizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="41"/>
        <source>Remote dir has outstanding progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="43"/>
        <source>A device is paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="45"/>
        <source>Local dir is out of sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="47"/>
        <source>Unread notification present</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
